==> hint-6.0.4.tgz: package/docs/about/PROJECT_CHARTER.md <==
# webhint charter

This project charter serves as a statement of scope and objectives for
the **webhint** project.

## 1. Guiding principles

The **webhint** project is part of the [OpenJS Foundation], which
operates transparently, openly, collaboratively, and ethically. Project
proposals, timelines, and status must not merely be open, but also easily
visible to outsiders.

## 2. Scope

Webhint's goal is to help web developers create better websites by
providing feedback and best practices guidance in several areas such
as (but not limited to) accessibility, security, performance, etc.

Webhint should be useful during all the development lifecycle and
adapt its feedback to each stage and the users' needs.

Every website has a unique set of requirements and webhint should
allow the developer to easily configure it to get the feedback
relevant to them.

## 3. Relationship with OpenJS Foundation CPC

Technical leadership for the projects within the [OpenJS Foundation] is
delegated to the projects through their project charters by the
[OpenJS Foundation Cross-Project Council][] (CPC). In the case of the
webhint project, it is delegated to the webhint Technical Steering
Committee ("TSC"). OpenJS Foundation's business leadership is the Board
of Directors (the "Board").

### 3.1 Other Formal Project Relationships

Section Intentionally Left Blank

## 4. Webhint's Governing Body

Webhint is governed by its maintainers. See [GOVERNANCE.md] for more
information.

## 5. Roles & Responsibilities

The roles and responsibilities of webhint's maintainers are described
in [GOVERNANCE.md].

### 5.1. Project Operations & Management

Section Intentionally Left Blank

### 5.2. Decision-making, Voting, and/or Elections (optional)

Webhint uses a consensus-seeking process, described in [GOVERNANCE.md].

### 5.3: Other Project Roles (optional)

Section Intentionally Left Blank

## 6. Definitions

Section Intentionally Left Blank

<!-- Link labels -->

[GOVERNANCE.md]: https://github.com/webhintio/hint/blob/master/packages/hint/docs/about/GOVERNANCE.md
[OpenJS Foundation Cross-Project Council]: https://openjsf.org/about/governance/

==> hint-6.0.6.tgz: package/docs/about/PROJECT_CHARTER.md <==
# webhint charter

This project charter serves as a statement of scope and objectives for
the **webhint** project.

## 1. Guiding principles

The **webhint** project is part of the [OpenJS Foundation], which
operates transparently, openly, collaboratively, and ethically. Project
proposals, timelines, and status must not merely be open, but also easily
visible to outsiders.

## 2. Scope

Webhint's goal is to help web developers create better websites by
providing feedback and best practices guidance in several areas such
as (but not limited to) accessibility, security, performance, etc.

Webhint should be useful during all the development lifecycle and
adapt its feedback to each stage and the users' needs.

Every website has a unique set of requirements and webhint should
allow the developer to easily configure it to get the feedback
relevant to them.

## 3. Relationship with OpenJS Foundation CPC

Technical leadership for the projects within the [OpenJS Foundation] is
delegated to the projects through their project charters by the
[OpenJS Foundation Cross-Project Council][] (CPC). In the case of the
webhint project, it is delegated to the webhint Technical Steering
Committee ("TSC"). OpenJS Foundation's business leadership is the Board
of Directors (the "Board").

### 3.1 Other Formal Project Relationships

Section Intentionally Left Blank

## 4. Webhint's Governing Body

Webhint is governed by its maintainers. See [GOVERNANCE.md][] for more
information.

## 5. Roles & Responsibilities

The roles and responsibilities of webhint's maintainers are described
in [GOVERNANCE.md][].

### 5.1. Project Operations & Management

Section Intentionally Left Blank

### 5.2. Decision-making, Voting, and/or Elections (optional)

Webhint uses a consensus-seeking process, described in [GOVERNANCE.md][].

### 5.3: Other Project Roles (optional)

Section Intentionally Left Blank

## 6. Definitions

Section Intentionally Left Blank

<!-- Link labels -->

[GOVERNANCE.md]: https://github.com/webhintio/hint/blob/master/packages/hint/docs/about/GOVERNANCE.md
[OpenJS Foundation Cross-Project Council]: https://openjsf.org/about/governance/
